@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
 #
-# listadmin version 2.30
+# listadmin version 2.31
 # Written 2003 - 2006 by
 # Kjetil Torgrim Homme <kjetilho+listadmin@ifi.uio.no>
 #
@@ -95,7 +95,7 @@ for (@lists) {
 
     my $info = {};
     my $tries = 0;
-    print "\nfetching data for $list ... ";
+    print "fetching data for $list ... ";
     do {
 	if (-t && ($pw eq "" || $info->{'autherror'})) {
 	    print "\n" unless $tries++;
@@ -155,6 +155,7 @@ _END_
 	    }
 	}
     }
+    print "\n";
 
     commit_changes ($list, $user, $pw, $config->{$list}{"adminurl"},
 		    \%change, $info, $config->{$list}{"logfile"});
@@ -486,8 +487,12 @@ sub get_list {
 	    last;
 	}
     }
-    die "Can not find version information in, please mail maintainer."
-	    unless $mmver;
+    unless ($mmver) {
+	if ($page =~ /no such list/i) {
+	    return {'servererror' => "No such list", 'url' => $url}
+	}
+	die "Can not find version information in, please mail maintainer.";
+    }
 
     if ($mmver ge "2.1") {
 	# Mailman does not look for "details" in parameters, so it
@@ -696,14 +701,17 @@ sub parse_approval {
     # The name of the header is flexible.
     my $header_re = $config->{"spamheader"} || 'X-\S*spam-?(?:level|score)';
 
-    # Extract the length from all spam score headers, sort them in
-    # descending order, and pick the front (max) element:
-    my ($score) = sort {$b <=> $a}
-                  map {length} 
-                  $headers =~ /^$header_re:\s+
-			       (?:\d+\.\d+\s+)? \(?(\S+)\)?/xgim;
-
-    $data->{$id}->{"spamscore"} = $score || 0;
+    # Extract all spam score headers, and pick the max value:
+    my $spamscore = 0;
+    while ($headers =~ /^$header_re:\s+
+	                   (-?\d+\.\d+\s+)?
+                           \(?
+                             ((\S)\3*)
+                           (?:\s|\)|$)/xgim) {
+	my $score = defined $1 ? int($1): length($2);
+	$spamscore = $score if $score > $spamscore;
+    }
+    $data->{$id}->{"spamscore"} = $spamscore;
     $data->{$id}->{"date"} = "<no date>";
     $data->{$id}->{"date"} = $1
 	    if $headers =~ /^Date:\s+(.*)$/m;
